==> odin_bot_exchanges-0.3.3-py3-none-any.whl: odin_bot_exchanges/currencies.py <==
CURRENCIES = ["USD", "EUR", "CLP"]

STABLE_COINS = ["DAI", "USDT"]

COINS = [
    "BTC",
    "ETH",
    "LTC",
    "XRP",
    "BCH",
    "TRX",
    "DASH",
    "XLM",
    "EOS",
    "DOT",
]

BALANCE_COINS = [*COINS, *STABLE_COINS, *CURRENCIES]


KRAKEN_MINIMUM = {
    "AAVE": 0.05,
    "ALGO": 15,
    "ANT": 2,
    "REP": 0.3,
    "REPV2": 0.3,
    "BAL": 0.3,
    "BAT": 30,
    "XXBT": 0.0002,
    "XBT": 0.0002,
    "BCH": 0.02,
    "ADA": 25,
    "LINK": 0.5,
    "COMP": 0.05,
    "ATOM": 1,
    "CRV": 10,
    "DAI": 5,
    "DASH": 0.05,
    "EOS": 2.5,
    "XETH": 0.005,
    "ETH": 0.005,
    "ETH2.S": 0.02,
    "XLTC": 0.05,
    "LTC": 0.05,
    "XXRP": 20,
    "XRP": 20,
    "XXLM": 20,
    "XLM": 20,
    "USDT": 5,
    "TRX": 250,
    "DOT": 0.2,
}

MINIMUM_TO_TRADE = {"kraken": KRAKEN_MINIMUM}

CEROS = {
    "USDT": 8,
    "BTC": 8,
    "DAI": 8,
    "ETH": 8,
    "BNB": 8,
    "LTC": 8,
    "BCH": 8,
    "CHA": 8,
    "LUK": 8,
    "DASH": 8,
    "XLM": 7,
    "XRP": 6,
    "TRX": 6,
    "DOT": 8,
    "CLP": 0,
    "EOS": 4,
    "USD": 2,
    "EUR": 2,
    "POL": 4,
}


KRAKEN_RENAME_COINS = {
    "XXBT": "BTC",
    "XBT": "BTC",
    "XETH": "ETH",
    "ETH": "ETH",
    "DASH": "DASH",
    "ZUSD": "USD",
    "USD": "USDT",
    "USDT": "USDT",
    "XXRP": "XRP",
    "XRP": "XRP",
    "XXLM": "XLM",
    "XLM": "XLM",
    "XLTC": "LTC",
    "LTC": "LTC",
    "DAI": "DAI",
    "BCH": "BCH",
    "TRX": "TRX",
    "EOS": "EOS",
    "ZEUR": "EUR",
    "PAXG": "PAX",
    "DOT": "DOT",
    "USDC": "USDC",
}

KRAKEN_RENAME_PAIRS = {
    "EOSUSDT": "EOS/USDT",
    "XRPUSDT": "XRP/USDT",
    "XBTUSDT": "BTC/USDT",
    "ETHUSDT": "ETH/USDT",
    "XLTCUSDT": "LTC/USDT",
    "LTCUSDT": "LTC/USDT",
    "BCHUSDT": "BCH/USDT",
    "DAIUSDT": "DAI/USDT",
    "ATOMUSDT": "ATOM/USDT",
    "DOTUSDT": "DOT/USDT",
    "PAXGUSD": "PAX/USD",
    "USDCUSDT": "USDC/USDT",
    "XXLMZUSD": "XLM/USD",
    "TRXUSD": "TRX/USD",
    "XXRPZUSD": "XRP/USD",
    "XLTCZUSD": "LTC/USD",
    "DASHUSD": "DASH/USD",
    "XETHZUSD": "ETH/USD",
    "XXBTZUSD": "BTC/USD",
    "USDTZUSD": "USDT/USD",
    "USDCZUSD": "USDC/USD",
    "EOSUSD": "EOS/USD",
    "DAIUSD": "DAI/USD",
    "DOTUSD": "DOT/USD",
    "XDGUSD": "XDG/USD",
    "ADAZUSD": "ADA/USD",
    "USDCUSD": "USDC/USD",
    "USDTEUR": "USDT/EUR",
    "XXBTZEUR": "BTC/EUR",
    "ATOMUSD": "ATOM/USD"
}

KRAKEN_RENAME_COINS_INV = {v: k for k, v in KRAKEN_RENAME_COINS.items()}

ORIONX_RENAME_COINS = {
    "BTC": "BTC",
    "ETH": "ETH",
    "DASH": "DASH",
    "DAI": "DAI",
    "USDT": "USDT",
    "LTC": "LTC",
    "XRP": "XRP",
    "BCH": "BCH",
    "TRX": "TRX",
    "XLM": "XLM",
    "EOS": "EOS",
}

ORIONX_RENAME_COINS_INV = {v: k for k, v in ORIONX_RENAME_COINS.items()}

LOANS_RENAME_COINS = {
    "BTC": "BTC",
    "ETH": "ETH",
    "DASH": "DASH",
    "DAI": "DAI",
    "USDT": "USDT",
    "LTC": "LTC",
    "XRP": "XRP",
    "BCH": "BCH",
    "TRX": "TRX",
    "XLM": "XLM",
    "EOS": "EOS",
}

LOANS_RENAME_COINS_INV = {v: k for k, v in LOANS_RENAME_COINS.items()}

BINANCE_RENAME_COINS = {"BTC": "BTC"}

BINANCE_RENAME_COINS_INV = {v: k for k, v in BINANCE_RENAME_COINS.items()}

RENAME_COINS = {
    "kraken": KRAKEN_RENAME_COINS,
    "orionX": ORIONX_RENAME_COINS,
    "loans": LOANS_RENAME_COINS,
    "binance": BINANCE_RENAME_COINS,
}

RENAME_COINS_INV = {
    "kraken": KRAKEN_RENAME_COINS_INV,
    "orionX": ORIONX_RENAME_COINS_INV,
    "loans": LOANS_RENAME_COINS_INV,
    "binance": BINANCE_RENAME_COINS_INV,
}

KRAKEN_FEE = 0.0016

==> odin_bot_exchanges-0.4.3-py3-none-any.whl: odin_bot_exchanges/currencies.py <==
CURRENCIES = ["USD", "EUR", "CLP"]

STABLE_COINS = ["DAI", "USDT"]

COINS = [
    "BTC",
    "ETH",
    "LTC",
    "XRP",
    "BCH",
    "TRX",
    "DASH",
    "XLM",
    "EOS",
    "DOT",
]

BALANCE_COINS = [*COINS, *STABLE_COINS, *CURRENCIES]


KRAKEN_MINIMUM = {
    "AAVE": 0.05,
    "ALGO": 15,
    "ANT": 2,
    "REP": 0.3,
    "REPV2": 0.3,
    "BAL": 0.3,
    "BAT": 30,
    "XXBT": 0.0002,
    "XBT": 0.0002,
    "BCH": 0.02,
    "ADA": 25,
    "LINK": 0.5,
    "COMP": 0.05,
    "ATOM": 1,
    "CRV": 10,
    "DAI": 5,
    "DASH": 0.05,
    "EOS": 2.5,
    "XETH": 0.005,
    "ETH": 0.005,
    "ETH2.S": 0.02,
    "XLTC": 0.05,
    "LTC": 0.05,
    "XXRP": 20,
    "XRP": 20,
    "XXLM": 20,
    "XLM": 20,
    "USDT": 5,
    "TRX": 250,
    "DOT": 0.2,
}

MINIMUM_TO_TRADE = {"kraken": KRAKEN_MINIMUM}

CEROS = {
    "USDT": 8,
    "BTC": 8,
    "DAI": 8,
    "ETH": 8,
    "BNB": 8,
    "LTC": 8,
    "BCH": 8,
    "CHA": 8,
    "LUK": 8,
    "DASH": 8,
    "XLM": 7,
    "XRP": 6,
    "TRX": 6,
    "DOT": 8,
    "CLP": 0,
    "EOS": 4,
    "USD": 2,
    "EUR": 2,
    "POL": 4,
}


KRAKEN_RENAME_COINS = {
    "XXBT": "BTC",
    "XBT": "BTC",
    "XETH": "ETH",
    "ETH": "ETH",
    "DASH": "DASH",
    "ZUSD": "USD",
    "USD": "USDT",
    "USDT": "USDT",
    "XXRP": "XRP",
    "XRP": "XRP",
    "XXLM": "XLM",
    "XLM": "XLM",
    "XLTC": "LTC",
    "LTC": "LTC",
    "DAI": "DAI",
    "BCH": "BCH",
    "TRX": "TRX",
    "EOS": "EOS",
    "ZEUR": "EUR",
    "PAXG": "PAX",
    "DOT": "DOT",
    "USDC": "USDC",
}

KRAKEN_RENAME_PAIRS = {
    "EOSUSDT": "EOS/USDT",
    "XRPUSDT": "XRP/USDT",
    "XBTUSDT": "BTC/USDT",
    "ETHUSDT": "ETH/USDT",
    "XLTCUSDT": "LTC/USDT",
    "LTCUSDT": "LTC/USDT",
    "BCHUSDT": "BCH/USDT",
    "DAIUSDT": "DAI/USDT",
    "SOLUSDT": "SOL/USDT",
    "ATOMUSDT": "ATOM/USDT",
    "ADAUSDT": "ADA/USDT",
    "DOTUSDT": "DOT/USDT",
    "BCHUSDT": "BCH/USDT",
    "PAXGUSD": "PAX/USD",
    "USDCUSDT": "USDC/USDT",
    "XXLMZUSD": "XLM/USD",
    "TRXUSD": "TRX/USD",
    "XXRPZUSD": "XRP/USD",
    "XLTCZUSD": "LTC/USD",
    "DASHUSD": "DASH/USD",
    "XETHZUSD": "ETH/USD",
    "XXBTZUSD": "BTC/USD",
    "USDTZUSD": "USDT/USD",
    "USDCZUSD": "USDC/USD",
    "EOSUSD": "EOS/USD",
    "DAIUSD": "DAI/USD",
    "DOTUSD": "DOT/USD",
    "XDGUSD": "XDG/USD",
    "ADAZUSD": "ADA/USD",
    "ADAUSD": "ADA/USD",
    "ATOMUSD": "ATOM/USD",
    "SOLUSD": "SOL/USD",
    "BCHUSD": "BCH/USD",
    "USDCUSD": "USDC/USD",
    "USDTEUR": "USDT/EUR",
    "XXBTZEUR": "BTC/EUR",
}

KRAKEN_RENAME_COINS_INV = {v: k for k, v in KRAKEN_RENAME_COINS.items()}

ORIONX_RENAME_COINS = {
    "BTC": "BTC",
    "ETH": "ETH",
    "DASH": "DASH",
    "DAI": "DAI",
    "USDT": "USDT",
    "LTC": "LTC",
    "XRP": "XRP",
    "BCH": "BCH",
    "TRX": "TRX",
    "XLM": "XLM",
    "EOS": "EOS",
}

ORIONX_RENAME_COINS_INV = {v: k for k, v in ORIONX_RENAME_COINS.items()}

LOANS_RENAME_COINS = {
    "BTC": "BTC",
    "ETH": "ETH",
    "DASH": "DASH",
    "DAI": "DAI",
    "USDT": "USDT",
    "LTC": "LTC",
    "XRP": "XRP",
    "BCH": "BCH",
    "TRX": "TRX",
    "XLM": "XLM",
    "EOS": "EOS",
}

LOANS_RENAME_COINS_INV = {v: k for k, v in LOANS_RENAME_COINS.items()}

BINANCE_RENAME_COINS = {"BTC": "BTC"}

BINANCE_RENAME_COINS_INV = {v: k for k, v in BINANCE_RENAME_COINS.items()}

RENAME_COINS = {
    "kraken": KRAKEN_RENAME_COINS,
    "orionX": ORIONX_RENAME_COINS,
    "loans": LOANS_RENAME_COINS,
    "binance": BINANCE_RENAME_COINS,
}

RENAME_COINS_INV = {
    "kraken": KRAKEN_RENAME_COINS_INV,
    "orionX": ORIONX_RENAME_COINS_INV,
    "loans": LOANS_RENAME_COINS_INV,
    "binance": BINANCE_RENAME_COINS_INV,
}

KRAKEN_FEE = 0.0016
